pub struct MultiConsumerTailerConfig {
pub directory: Utf8PathBuf,
pub pattern: String,
pub poll_watcher: Option<Duration>,
pub tail: bool,
pub consumers: Vec<ConsumerConfig>,
}Expand description
Configuration for a tailer that fans out records to multiple consumers.
Fields
directory: Utf8PathBufThe directory containing zstd-compressed JSONL log files.
pattern: StringGlob pattern for matching log filenames.
poll_watcher: Option<Duration>If set, use a polling-based filesystem watcher.
tail: boolIf true, ignore checkpoints and start from the most recent segment.
consumers: Vec<ConsumerConfig>The set of consumers that receive records.
Implementations
Sourceimpl MultiConsumerTailerConfig
impl MultiConsumerTailerConfig
pub fn new(directory: Utf8PathBuf, consumers: Vec<ConsumerConfig>) -> Self
pub fn pattern(self, pattern: impl Into<String>) -> Self
pub fn poll_watcher(self, interval: Duration) -> Self
pub fn tail(self, enable: bool) -> Self
Sourcepub async fn build(self) -> Result<MultiConsumerTailer>
pub async fn build(self) -> Result<MultiConsumerTailer>
Build the multi-consumer tailer.